==> libgrinvin-core-java_1.0.4.orig.tar.gz: grinvin-core-1.0.4/org/grinvin/help/FactoryListHelpManager.java <==
/* FactoryListHelpManager.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.help;

import java.awt.AWTEvent;
import java.awt.Component;
import java.awt.Point;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;
import javax.help.CSH.Manager;
import javax.help.HelpSet;

import org.grinvin.factories.graphs.GraphFactory;
import org.grinvin.list.FactoryList;

/**
 * Provides dynamic map ID assignment for the list of graph factories.
 */
public class FactoryListHelpManager implements Manager {
    
    private final FactoryList list;
    
    /** Creates a new instance of FactoryListHelpManager */
    public FactoryListHelpManager(FactoryList list) {
        this.list = list;
    }
    
    public HelpSet getHelpSet(Object object, AWTEvent aWTEvent) {
        return HelpManager.getHelpSet();
    }
    
    public String getHelpIDString(Object object, AWTEvent aWTEvent) {
        if(object.equals(list)){
            if(aWTEvent instanceof MouseEvent){
                MouseEvent e = (MouseEvent) aWTEvent;
                Point parentPosition = ((Component)e.getSource()).getLocationOnScreen();
                Point listPosition = list.getLocationOnScreen();
                e.translatePoint(parentPosition.x - listPosition.x, parentPosition.y - listPosition.y);
                int selectedIndex = list.locationToIndex(e.getPoint());
                if(selectedIndex >= 0) {
                    list.getSelectionModel().setSelectionInterval(selectedIndex, selectedIndex);
                    return  ((GraphFactory)list.getSelectedValue()).getId();
                } else
                    return null;
            } else if (aWTEvent instanceof ActionEvent) {
                Object selection = list.getSelectedValue();
                if(selection==null)
                    return null;
                else 
                    return ((GraphFactory)selection).getId();
            } else
                return null;
        } else
            return null;
    }
    
}

==> libgrinvin-core-java_1.2.orig.tar.gz: grinvin-core-1.2/org/grinvin/help/FactoryListHelpManager.java <==
/* FactoryListHelpManager.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.help;

import java.awt.AWTEvent;
import java.awt.Component;
import java.awt.Point;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;
import javax.help.CSH.Manager;
import javax.help.HelpSet;

import org.grinvin.factories.graphs.GraphFactory;
import org.grinvin.gui.components.FactoryCellListComponent;

/**
 * Provides dynamic map ID assignment for the list of graph factories.
 */
public class FactoryListHelpManager implements Manager {
    
    private final FactoryCellListComponent list;
    
    /** Creates a new instance of FactoryListHelpManager */
    public FactoryListHelpManager(FactoryCellListComponent list) {
        this.list = list;
    }
    
    public HelpSet getHelpSet(Object object, AWTEvent aWTEvent) {
        return HelpManager.getHelpSet();
    }
    
    public String getHelpIDString(Object object, AWTEvent aWTEvent) {
        if(object.equals(list)){
            if(aWTEvent instanceof MouseEvent){
                MouseEvent e = (MouseEvent) aWTEvent;
                Point parentPosition = ((Component)e.getSource()).getLocationOnScreen();
                Point listPosition = list.getLocationOnScreen();
                e.translatePoint(parentPosition.x - listPosition.x, parentPosition.y - listPosition.y);
                int selectedIndex = list.locationToIndex(e.getPoint());
                if(selectedIndex >= 0) {
                    list.getSelectionModel().setSelectionInterval(selectedIndex, selectedIndex);
                    return  ((GraphFactory)list.getSelectedValue()).getId();
                } else
                    return null;
            } else if (aWTEvent instanceof ActionEvent) {
                Object selection = list.getSelectedValue();
                if(selection==null)
                    return null;
                else 
                    return ((GraphFactory)selection).getId();
            } else
                return null;
        } else
            return null;
    }
    
}
